import 'dart:developer';

import 'package:cached_network_image/cached_network_image.dart';
import 'package:flutter/material.dart';
import 'package:google_fonts/google_fonts.dart';
import 'package:hub/backend/api_requests/api_calls.dart';
import 'package:hub/components/organism_components/bottom_arrow_linked_locals_component/bottom_arrow_linked_locals_component_widget.dart';
import 'package:hub/shared/utils/dialog_util.dart';
import 'package:hub/shared/utils/storage_util.dart';

import '/flutter_flow/custom_functions.dart' as functions;
import '/flutter_flow/flutter_flow_theme.dart';
import '/flutter_flow/flutter_flow_util.dart';
import 'local_profile_component_model.dart';

export 'local_profile_component_model.dart';

class LocalProfileComponentWidget extends StatefulWidget {
  const LocalProfileComponentWidget({super.key});

  @override
  State<LocalProfileComponentWidget> createState() =>
      _LocalProfileComponentWidgetState();
}

class _LocalProfileComponentWidgetState
    extends State<LocalProfileComponentWidget> {
  late LocalProfileComponentModel _model;

  @override
  void setState(VoidCallback callback) {
    super.setState(callback);
    _model.onUpdate();
  }

  @override
  void initState() {
    super.initState();
    _model = createModel(context, () => LocalProfileComponentModel());
    _model.setOnUpdate(onUpdate: () => setState(() {}));
    _model.setStateCallback = () => safeSetState(() {});

    () async {
      await processLocals();
    }();
  }

  @override
  void dispose() {
    _model.maybeDispose();

    super.dispose();
  }

  Future<void> processData() async {
    try {
      final GetDadosCall callback = PhpGroup.getDadosCall;

      var response = await callback.call();

      final error = response.jsonBody['error'];
      // final errorMsg = response.jsonBody['error_msg'];

      if (error == false) {
        final bool whatsapp = response.jsonBody['whatsapp'] ?? false;
        final bool provisional = response.jsonBody['provisional'] ?? false;
        final bool pets = response.jsonBody['pet'] ?? false;
        final String petAmountRegister =
            response.jsonBody['petAmountRegister'].toString().isEmpty
                ? '0'
                : response.jsonBody['petAmountRegister'].toString();
        final String name = response.jsonBody['visitado']['VDO_NOME'];

        StorageUtil().whatsapp = whatsapp;
        StorageUtil().provisional = provisional;
        StorageUtil().pets = pets;
        StorageUtil().petAmountRegister = petAmountRegister;
        StorageUtil().userName = name;

        safeSetState(() {});
        return;
      } else if (error == true) {
        DialogUtil.warningDefault(context).whenComplete(() => processLocals());
        safeSetState(() {});
      }

      return;
    } catch (e) {
      log('() => error: $e'); // Add this line to log the error
      DialogUtil.warningDefault(context).whenComplete(() => processLocals());
    }
  }

  Future<void> processLocals() async {
    try {
      final GetLocalsCall callback = PhpGroup.getLocalsCall;

      final cliUUID = StorageUtil().cliUUID;
      final cliName = StorageUtil().cliName;
      var response = await callback.call();

      List<dynamic> locals = response.jsonBody['locais'] ?? [];

      final activeLocals =
          locals.where((local) => local['CLU_STATUS'] == 'A').toList();

      if (activeLocals.isEmpty || cliUUID.isEmpty || cliName.isEmpty) {
        await showModalSelectLocal();
      } else {
        await processData();
      }
    } catch (e) {
      await showModalSelectLocal();
    }
  }

  Future<void> showModalSelectLocal() async {
    await showModalBottomSheet(
      isScrollControlled: true,
      backgroundColor: Colors.transparent,
      enableDrag: false,
      isDismissible: false,
      showDragHandle: false,
      useSafeArea: true,
      context: context,
      builder: (context) => PopScope(
        canPop: false,
        child: Padding(
          padding: MediaQuery.viewInsetsOf(context),
          child: const BottomArrowLinkedLocalsComponentWidget(),
        ),
      ),
    ).then((_) async {
      onUpdate();
    });

    await processData();
  }

  void onUpdate() {
    safeSetState(() {
      _model.getData();
    });
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: const BoxDecoration(),
      child: Align(
        alignment: const AlignmentDirectional(0.0, -1.0),
        child: Material(
          color: Colors.transparent,
          elevation: 0.0,
          child: Container(
            width: double.infinity,
            height: 119.0,
            decoration: BoxDecoration(
              color: FlutterFlowTheme.of(context).primary,
              border: Border.all(
                color: FlutterFlowTheme.of(context).primary,
              ),
            ),
            child: Row(
              mainAxisSize: MainAxisSize.max,
              children: [
                Align(
                  alignment: const AlignmentDirectional(-1.0, 0.0),
                  child: Padding(
                    padding: const EdgeInsets.all(2.0),
                    child: InkWell(
                        splashColor: Colors.transparent,
                        focusColor: Colors.transparent,
                        hoverColor: Colors.transparent,
                        highlightColor: Colors.transparent,
                        onTap: () async {
                          showModalSelectLocal();
                        },
                        child: ClipRRect(
                          borderRadius: BorderRadius.circular(200.0),
                          child: CachedNetworkImage(
                            imageBuilder: (context, imageProvider) => Container(
                              decoration: BoxDecoration(
                                image: DecorationImage(
                                  image: imageProvider,
                                  fit: BoxFit.cover,
                                ),
                              ),
                            ),
                            imageUrl: valueOrDefault(
                                'https://freaccess.com.br/freaccess/Images/Clients/${_model.cliUUID}.png',
                                'assets/images/home.png'),
                            width: 80.0,
                            height: 80.0,
                            fit: BoxFit.cover,
                            alignment: const Alignment(0.0, 0.0),
                            placeholder: (context, url) =>
                                Image.asset('assets/images/home.png'),
                            errorListener: (_) =>
                                Image.asset('assets/images/home.png'),
                            errorWidget: (_, __, ___) =>
                                Image.asset('assets/images/home.png'),
                          ),
                        )),
                  ),
                ),
                Text(
                  valueOrDefault<String>(
                    functions.convertToUppercase(_model.cliName),
                    FFLocalizations.of(context).getVariableText(
                      ptText: 'SEM LOCAL VINCULADO',
                      enText: 'NO LINKED LOCAL',
                    ),
                  ),
                  style: FlutterFlowTheme.of(context).labelMedium.override(
                        fontFamily: 'Nunito',
                        color: FlutterFlowTheme.of(context).info,
                        fontSize: 14.0,
                        letterSpacing: 0.0,
                        fontWeight: FontWeight.w500,
                        useGoogleFonts:
                            GoogleFonts.asMap().containsKey('Nunito'),
                      ),
                ),
              ]
                  .divide(const SizedBox(width: 20.0))
                  .addToStart(const SizedBox(width: 20.0))
                  .addToEnd(const SizedBox(width: 20.0)),
            ),
          ),
        ),
      ),
    );
  }
}
